@@ -306,18 +306,15 @@ class Tapo:
         )
         return data["cet"]["media_encrypt"]
 
-    def getMediaEncrypt(self):
-        data = {"method": "get", "cet": {"name": ["media_encrypt"]}}
-        return self.performRequest(data)["cet"]["media_encrypt"]
-
     def getMotionDetection(self):
         return self.executeFunction(
             "getDetectionConfig", {"motion_detection": {"name": ["motion_det"]}},
         )["motion_detection"]["motion_det"]
 
     def getPersonDetection(self):
-        data = {"method": "get", "people_detection": {"name": ["detection"]}}
-        return self.performRequest(data)["people_detection"]["detection"]
+        return self.executeFunction(
+            "getPersonDetectionConfig", {"people_detection": {"name": ["detection"]}},
+        )["people_detection"]["detection"]
 
     def getAlarm(self):
         # ensure reverse compatibility, simulate the same response for children devices
@@ -552,8 +549,7 @@ class Tapo:
 
     def setPersonDetection(self, enabled, sensitivity=False):
         data = {
-            "method": "set",
-            "people_detection": {"detection": {"enabled": "on" if enabled else "off"}},
+            "people_detection": {"detection": {"enabled": "on" if enabled else "off"}}
         }
         if sensitivity:
             if sensitivity == "high":
@@ -565,7 +561,7 @@ class Tapo:
             else:
                 raise Exception("Invalid sensitivity, can be low, normal or high")
 
-        return self.performRequest(data)
+        return self.executeFunction("setPersonDetectionConfig", data)
 
     def setAutoTrackTarget(self, enabled):
         return self.executeFunction(
@@ -789,6 +785,10 @@ class Tapo:
                         "method": "getDetectionConfig",
                         "params": {"motion_detection": {"name": ["motion_det"]}},
                     },
+                    {
+                        "method": "getPersonDetectionConfig",
+                        "params": {"people_detection": {"name": ["detection"]}},
+                    },
                     {
                         "method": "getLensMaskConfig",
                         "params": {"lens_mask": {"name": ["lens_mask_info"]}},
